@@ -1723,6 +1723,24 @@ def search(
 )
 @click.argument("dbtable")
 @click.option("-c", "--column", type=str, multiple=True, help="Columns to return")
+@click.option("--where", help="Optional where clause")
+@click.option(
+    "-p",
+    "--param",
+    multiple=True,
+    type=(str, str),
+    help="Named :parameters for where clause",
+)
+@click.option(
+    "--limit",
+    type=int,
+    help="Number of rows to return - defaults to everything",
+)
+@click.option(
+    "--offset",
+    type=int,
+    help="SQL offset to use",
+)
 @output_options
 @load_extension_option
 @click.pass_context
@@ -1731,6 +1749,10 @@ def rows(
     path,
     dbtable,
     column,
+    where,
+    param,
+    limit,
+    offset,
     nl,
     arrays,
     csv,
@@ -1745,10 +1767,17 @@ def rows(
     columns = "*"
     if column:
         columns = ", ".join("[{}]".format(c) for c in column)
+    sql = "select {} from [{}]".format(columns, dbtable)
+    if where:
+        sql += " where " + where
+    if limit:
+        sql += " limit {}".format(limit)
+    if offset:
+        sql += " offset {}".format(offset)
     ctx.invoke(
         query,
         path=path,
-        sql="select {} from [{}]".format(columns, dbtable),
+        sql=sql,
         nl=nl,
         arrays=arrays,
         csv=csv,
@@ -1756,6 +1785,7 @@ def rows(
         no_headers=no_headers,
         table=table,
         fmt=fmt,
+        param=param,
         json_cols=json_cols,
         load_extension=load_extension,
     )
